@@ -12,13 +12,14 @@ from inspect import currentframe
 import time
 import locale
 import platform
-from numpy import array
 import pymysql
 import paramiko
 import minio
 import redis
 import uuid
 
+from sqlalchemy import true
+
 
 class UniUtil:
     """统一处理工具类"""
@@ -490,7 +491,7 @@ class InfluxUtil:
     def exec_sql(cls, conf: dict, sql: str):
         """执行influxdb查询sql"""
         cls._init(conf)
-        return list(cls.CONN.query(sql).get_points())
+        return list(cls.CONN.query(sql, epoch='ms', chunked=true).get_points())
 
     @classmethod
     def write_data(cls, conf: dict, tbl: str, data_list: list):
